@@ -3,7 +3,7 @@ cv.ncvreg <- function(X, y, ..., cluster, nfolds=10, seed, cv.ind, trace=FALSE)
   ## Error checking
   if (!missing(seed)) set.seed(seed)
   if (class(X) != "matrix") {
-    tmp <- try(X <- as.matrix(X), silent=TRUE)
+    tmp <- try(X <- model.matrix(~0+., data=X), silent=TRUE)
     if (class(tmp)[1] == "try-error") stop("X must be a matrix or able to be coerced to a matrix")
   }
   if (class(y) != "numeric") {
