@@ -5,16 +5,18 @@ setupLambdaCox <- function(X, y, Delta, alpha, lambda.min, nlambda, penalty.fact
   ## Determine lambda.max
   ind <- which(penalty.factor!=0)
   if (length(ind)!=p) {
-    res <- .Call("cdfit_cox_dh", X, y, Delta, "lasso", 0, 0.001, as.integer(100), 3, penalty.factor, 
+    nullFit <- .Call("cdfit_cox_dh", X[, -ind, drop=FALSE], y, Delta, "lasso", 0, 0.001, as.integer(100), 3, penalty.factor[-ind], 
                     alpha, as.integer(p), as.integer(TRUE), as.integer(FALSE))
+    eta <- as.numeric(X[, -ind, drop=FALSE] %*% nullFit[[1]])
+    rsk <- rev(cumsum(rev(exp(eta))))
+    W <- outer(exp(eta), rsk, "/")
+    W[upper.tri(W)] <- 0
+    s <- Delta - W %*% Delta
   } else {
     w <- 1/(n-(1:n)+1)
-    h <- cumsum(Delta*w*(1-w))
     s <- Delta - cumsum(Delta*w)
-    r <- s/h
-    r[h==0] <- 0
   }
-  zmax <- .Call("maxprod", X, r * h, ind, penalty.factor) / n
+  zmax <- .Call("maxprod", X, s, ind, penalty.factor) / n
   lambda.max <- zmax/alpha
   
   if (lambda.min==0) lambda <- c(exp(seq(log(lambda.max),log(.001*lambda.max),len=nlambda-1)),0)
